"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const uuid_1 = require("uuid");
const useDragging_1 = __importDefault(require("./useDragging"));
const util_1 = require("./util");
function FileUpload({ onChange, fileValue, body, loadingBody, maxSize = 5, onError, type = ['jpg', 'jpeg', 'png'], overlap = true, className = '', }) {
    const containerRef = (0, react_1.useRef)(null);
    const inputRef = (0, react_1.useRef)(null);
    const [isLoading, setIsLoading] = (0, react_1.useState)(false);
    const onChangeFiles = (ev) => {
        if (isLoading)
            return;
        let isError = false;
        ev.preventDefault();
        ev.stopPropagation();
        setIsLoading(true);
        let selectFiles = [];
        let tempFiles = [];
        if (ev.type === 'drop') {
            selectFiles = ev.dataTransfer.files;
        }
        else {
            selectFiles = ev.target.files;
        }
        for (let i = 0; i < selectFiles.length; i++) {
            const file = selectFiles[i];
            if (!(0, util_1.checkType)(file, type)) {
                isError = true;
                if (onError)
                    onError('typeError');
            }
            if (maxSize && (0, util_1.getFileSizeMB)(file.size) > maxSize) {
                isError = true;
                if (onError)
                    onError('maxSizeError');
            }
            if (!overlap && (0, util_1.isOverlabFile)(fileValue, file)) {
                isError = true;
                if (onError)
                    onError('overlabError');
            }
            const preview = URL.createObjectURL(file);
            tempFiles = [...tempFiles, { id: `${(0, uuid_1.v4)()}`, file, preview }];
        }
        if (isError) {
            setIsLoading(false);
        }
        else {
            onChange([...fileValue, tempFiles].flat());
            setIsLoading(false);
        }
        inputRef.current.value = null;
    };
    const { isDragging } = (0, useDragging_1.default)({ onChangeFiles, containerRef });
    const setClassName = `${className} file_container${isDragging ? ' dragging' : ''}`;
    return ((0, jsx_runtime_1.jsxs)("div", Object.assign({ ref: containerRef, className: setClassName, "aria-hidden": true, style: {
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            position: 'relative',
            cursor: 'pointer',
            width: '100%',
            height: '100%',
        }, onClick: () => !isLoading && inputRef && inputRef.current.click() }, { children: [(0, jsx_runtime_1.jsx)("input", { ref: inputRef, multiple: true, style: { display: 'none' }, type: 'file', accept: 'image/*', onChange: onChangeFiles }), (0, jsx_runtime_1.jsxs)("div", Object.assign({ className: `file_container${isDragging ? ' dragging' : ''}` }, { children: [isLoading && loadingBody, !isLoading &&
                        (body ? body : ((0, jsx_runtime_1.jsx)("div", Object.assign({ className: 'temp_body', style: { fontSize: 17, fontWeight: 700 } }, { children: "Drag & Drop" }))))] }))] })));
}
exports.default = FileUpload;
//# sourceMappingURL=FileUpload.js.map