"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
function useDragging({ onChangeFiles, containerRef }) {
    const [isDragging, setIsDragging] = (0, react_1.useState)(false);
    const handleDragIn = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        e.stopPropagation();
    }, []);
    const handleDragOut = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        e.stopPropagation();
        setIsDragging(false);
    }, []);
    const handleDragOver = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        e.stopPropagation();
        if (e.dataTransfer.files) {
            setIsDragging(true);
        }
    }, []);
    const handleDrop = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        e.stopPropagation();
        onChangeFiles(e);
        setIsDragging(false);
    }, [onChangeFiles]);
    (0, react_1.useEffect)(() => {
        const ref = containerRef.current;
        if (ref) {
            ref.addEventListener('dragenter', handleDragIn);
            ref.addEventListener('dragleave', handleDragOut);
            ref.addEventListener('dragover', handleDragOver);
            ref.addEventListener('drop', handleDrop);
        }
        return () => {
            ref.removeEventListener('dragenter', handleDragIn);
            ref.removeEventListener('dragleave', handleDragOut);
            ref.removeEventListener('dragover', handleDragOver);
            ref.removeEventListener('drop', handleDrop);
        };
    }, [handleDragIn, handleDragOut, handleDragOver, handleDrop, containerRef]);
    return { isDragging };
}
exports.default = useDragging;
//# sourceMappingURL=useDragging.js.map