import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useRef, useState } from 'react';
import { v4 as uuidv4 } from 'uuid';
import useDragging from './useDragging';
import { checkType, getFileSizeMB, isOverlabFile } from './util';
function FileUpload({ onChange, fileValue, body, loadingBody, maxSize = 5, onError, type = ['jpg', 'jpeg', 'png'], overlap = true, className = '', }) {
    const containerRef = useRef(null);
    const inputRef = useRef(null);
    const [isLoading, setIsLoading] = useState(false);
    const onChangeFiles = (ev) => {
        if (isLoading)
            return;
        let isError = false;
        ev.preventDefault();
        ev.stopPropagation();
        setIsLoading(true);
        let selectFiles = [];
        let tempFiles = [];
        if (ev.type === 'drop') {
            selectFiles = ev.dataTransfer.files;
        }
        else {
            selectFiles = ev.target.files;
        }
        for (let i = 0; i < selectFiles.length; i++) {
            const file = selectFiles[i];
            if (!checkType(file, type)) {
                isError = true;
                if (onError)
                    onError('typeError');
            }
            if (maxSize && getFileSizeMB(file.size) > maxSize) {
                isError = true;
                if (onError)
                    onError('maxSizeError');
            }
            if (!overlap && isOverlabFile(fileValue, file)) {
                isError = true;
                if (onError)
                    onError('overlabError');
            }
            const preview = URL.createObjectURL(file);
            tempFiles = [...tempFiles, { id: `${uuidv4()}`, file, preview }];
        }
        if (isError) {
            setIsLoading(false);
        }
        else {
            onChange([...fileValue, tempFiles].flat());
            setIsLoading(false);
        }
        inputRef.current.value = null;
    };
    const { isDragging } = useDragging({ onChangeFiles, containerRef });
    const setClassName = `${className} file_container${isDragging ? ' dragging' : ''}`;
    return (_jsxs("div", Object.assign({ ref: containerRef, className: setClassName, "aria-hidden": true, style: {
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            position: 'relative',
            cursor: 'pointer',
            width: '100%',
            height: '100%',
        }, onClick: () => !isLoading && inputRef && inputRef.current.click() }, { children: [_jsx("input", { ref: inputRef, multiple: true, style: { display: 'none' }, type: 'file', accept: 'image/*', onChange: onChangeFiles }), _jsxs("div", Object.assign({ className: `file_container${isDragging ? ' dragging' : ''}` }, { children: [isLoading && loadingBody, !isLoading &&
                        (body ? body : (_jsx("div", Object.assign({ className: 'temp_body', style: { fontSize: 17, fontWeight: 700 } }, { children: "Drag & Drop" }))))] }))] })));
}
export default FileUpload;
//# sourceMappingURL=FileUpload.js.map