import { useCallback, useEffect, useState } from 'react';
function useDragging({ onChangeFiles, containerRef }) {
    const [isDragging, setIsDragging] = useState(false);
    const handleDragIn = useCallback((e) => {
        e.preventDefault();
        e.stopPropagation();
    }, []);
    const handleDragOut = useCallback((e) => {
        e.preventDefault();
        e.stopPropagation();
        setIsDragging(false);
    }, []);
    const handleDragOver = useCallback((e) => {
        e.preventDefault();
        e.stopPropagation();
        if (e.dataTransfer.files) {
            setIsDragging(true);
        }
    }, []);
    const handleDrop = useCallback((e) => {
        e.preventDefault();
        e.stopPropagation();
        onChangeFiles(e);
        setIsDragging(false);
    }, [onChangeFiles]);
    useEffect(() => {
        const ref = containerRef.current;
        if (ref) {
            ref.addEventListener('dragenter', handleDragIn);
            ref.addEventListener('dragleave', handleDragOut);
            ref.addEventListener('dragover', handleDragOver);
            ref.addEventListener('drop', handleDrop);
        }
        return () => {
            ref.removeEventListener('dragenter', handleDragIn);
            ref.removeEventListener('dragleave', handleDragOut);
            ref.removeEventListener('dragover', handleDragOver);
            ref.removeEventListener('drop', handleDrop);
        };
    }, [handleDragIn, handleDragOut, handleDragOver, handleDrop, containerRef]);
    return { isDragging };
}
export default useDragging;
//# sourceMappingURL=useDragging.js.map